"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }var _terserwebpackplugin = require('terser-webpack-plugin'); var _terserwebpackplugin2 = _interopRequireDefault(_terserwebpackplugin);
var _cssminimizerwebpackplugin = require('css-minimizer-webpack-plugin'); var _cssminimizerwebpackplugin2 = _interopRequireDefault(_cssminimizerwebpackplugin);
var _getUserConfig = require('./getUserConfig');
const getJsMinimizer = () => {
  const useProfile = process.env.USE_PROFILE === "true";
  const { minify, terserOptions } = _getUserConfig.getUserConfig.call(void 0, 
    "optimization.minimizer.jsMinimizer"
  );
  switch (minify) {
    case "uglifyJsMinify":
      return new (0, _terserwebpackplugin2.default)({
        minify: _terserwebpackplugin2.default.uglifyJsMinify,
        terserOptions
      });
    case "esbuildMinify":
      return new (0, _terserwebpackplugin2.default)({
        minify: _terserwebpackplugin2.default.esbuildMinify,
        terserOptions
      });
    case "swcMinify":
      return new (0, _terserwebpackplugin2.default)({
        minify: _terserwebpackplugin2.default.swcMinify,
        terserOptions
      });
    default:
      return new (0, _terserwebpackplugin2.default)({
        minify: _terserwebpackplugin2.default.terserMinify,
        terserOptions: _getUserConfig.deepMergeWithArray.call(void 0, terserOptions, {
          parse: {
            // We want terser to parse ecma 8 code. However, we don't want it
            // to apply any minification steps that turns valid ecma 5 code
            // into invalid ecma 5 code. This is why the 'compress' and 'output'
            // sections only apply transformations that are ecma 5 safe
            // https://github.com/facebook/create-react-app/pull/4234
            ecma: 2020
          },
          compress: {
            ecma: 5,
            // Disabled because of an issue with Uglify breaking seemingly valid code:
            // https://github.com/facebook/create-react-app/issues/2376
            // Pending further investigation:
            // https://github.com/mishoo/UglifyJS2/issues/2011
            comparisons: false,
            // Disabled because of an issue with Terser breaking valid code:
            // https://github.com/facebook/create-react-app/issues/5250
            // Pending further investigation:
            // https://github.com/terser-js/terser/issues/120
            inline: 2
          },
          mangle: {
            safari10: true
          },
          // Added for profiling in devtools
          keep_classnames: useProfile,
          keep_fnames: useProfile,
          output: {
            ecma: 5,
            comments: false,
            // Turned on because emoji and regex is not minified properly using default
            // https://github.com/facebook/create-react-app/issues/2488
            ascii_only: true
          }
        })
      });
  }
};
const getCssMinimizer = () => {
  const { minify, minimizerOptions } = _getUserConfig.getUserConfig.call(void 0, 
    "optimization.minimizer.cssMinimizer"
  );
  switch (minify) {
    case "cssoMinify":
      return new (0, _cssminimizerwebpackplugin2.default)({
        minify: _cssminimizerwebpackplugin2.default.cssoMinify,
        minimizerOptions
      });
    case "cleanCssMinify":
      return new (0, _cssminimizerwebpackplugin2.default)({
        minify: _cssminimizerwebpackplugin2.default.cleanCssMinify,
        minimizerOptions
      });
    case "esbuildMinify":
      return new (0, _cssminimizerwebpackplugin2.default)({
        minify: _cssminimizerwebpackplugin2.default.esbuildMinify,
        minimizerOptions
      });
    case "lightningCssMinify":
      return new (0, _cssminimizerwebpackplugin2.default)({
        minify: _cssminimizerwebpackplugin2.default.lightningCssMinify,
        minimizerOptions
      });
    case "swcMinify":
      return new (0, _cssminimizerwebpackplugin2.default)({
        minify: _cssminimizerwebpackplugin2.default.swcMinify,
        minimizerOptions
      });
    default:
      return new (0, _cssminimizerwebpackplugin2.default)({
        minify: _cssminimizerwebpackplugin2.default.cssnanoMinify,
        minimizerOptions: _getUserConfig.deepMergeWithArray.call(void 0, minimizerOptions, {
          preset: "default"
        })
      });
  }
};
const defaultSplitChunks = {
  chunks: "all",
  cacheGroups: {
    libs: {
      name: "chunk-libs",
      test: /[\\/]node_modules[\\/]/,
      priority: 10,
      chunks: "initial"
      // only package third parties that are initially dependent
    },
    antd: {
      name: "chunk-antd",
      // split elementUI into a single package
      priority: 12,
      // the weight needs to be larger than libs and app or it will be packaged into libs or app
      test: /[\\/]node_modules[\\/]_?antd(.*)/
      // in order to adapt to cnpm
    },
    elementUI: {
      name: "chunk-elementUI",
      // split elementUI into a single package
      priority: 22,
      // the weight needs to be larger than libs and app or it will be packaged into libs or app
      test: /[\\/]node_modules[\\/]_?element-ui(.*)/
      // in order to adapt to cnpm
    },
    d3: {
      name: "chunk-d3",
      // split d3 into a single package
      priority: 22,
      // the weight needs to be larger than libs and app or it will be packaged into libs or app
      test: /[\\/]node_modules[\\/]d3/
      // in order to adapt to cnpm
    },
    echarts: {
      name: "chunk-echarts",
      // split echarts into a single package
      priority: 22,
      // the weight needs to be larger than libs and app or it will be packaged into libs or app
      test: /[\\/]node_modules[\\/]echarts/
      // in order to adapt to cnpm
    },
    exceljs: {
      name: "chunk-exceljs",
      // split exceljs into a single package
      priority: 22,
      // the weight needs to be larger than libs and app or it will be packaged into libs or app
      test: /[\\/]node_modules[\\/]exceljs/
      // in order to adapt to cnpm
    },
    xlsx: {
      name: "chunk-xlsx",
      // split xlsx into a single package
      priority: 22,
      // the weight needs to be larger than libs and app or it will be packaged into libs or app
      test: /[\\/]node_modules[\\/]xlsx/
      // in order to adapt to cnpm
    }
  }
};
const getOptimization = () => {
  const isEnvProduction = process.env.NODE_ENV === "production";
  const splitChunks = _getUserConfig.getUserConfig.call(void 0, "optimization.splitChunks");
  return {
    minimize: isEnvProduction,
    splitChunks: isEnvProduction && _getUserConfig.deepMergeWithArray.call(void 0, splitChunks, defaultSplitChunks),
    minimizer: [
      // This is only used in production mode
      getJsMinimizer(),
      getCssMinimizer()
    ],
    runtimeChunk: true
  };
};


exports.getOptimization = getOptimization;
